nouns = [
    "cats",
    "dogs",
    "elephants",
    "mice",
    "snakes",
    "sheep",
    "cows",
    "flies",
    "lions",
    "dragons",
    "slugs",
    "eagles",
    "frogs",
    "parrots",
    "alligators",
    "sharks",
    "monkeys",
    "tigers",
    "moles",
    "badgers",
    "snails",
    "chickens",
    "rooster",
    "koalas",
    "kangaroos",
    "turtles",
    "iguanas",
    "antelopes",
    "springboks",
    "armadillos",
    "foxes",
    "zebras",
    "impalas",
    "llamas",
    "jaguars",
    "baboons",
    "horses",
    "porcupines",
    "pigs",
    "crocodiles",
    "bats",
    "sloths",
    "buffalo",
    "hamster",
    "wombat",
    "kittens",
    "puppies",
    "rats",
    "reindeer",
    "donkeys",
    "alpacas",
    "owls",
    "rabbits",
    "gophers",
    "cheetahs",
    "gorillas",
    "wolves",
    "beetles",
    "pandas",
    "newts",
    "beavers",
    "chimpanzees",
    "bees",
    "crows",
    "raccoons",
    "toads",
    "ferrets",
    "whales",
    "dolphins",
    "apes",
    "deer",
]

