verbs = [
    "exist",
    "discharge",
    "settle",
    "disappear",
    "coincide",
    "proceed",
    "test",
    "cancel",
    "request",
    "lean",
    "enclose",
    "march",
    "compose",
    "leave",
    "breed",
    "wander",
    "win",
    "set",
    "endorse",
    "bear",
    "spare",
    "gather",
    "hire",
    "cease",
    "subject",
    "back",
    "sing",
    "float",
    "greet",
    "recall",
    "touch",
    "lose",
    "proclaim",
    "burn",
    "hunt",
    "disagree",
    "consume",
    "apply",
    "fix",
    "couple",
    "estimate",
    "conform",
    "tour",
    "weigh",
    "deposit",
    "own",
    "convince",
    "suffer",
    "end",
    "limit",
    "operate",
    "round",
    "refuse",
    "speak",
    "declare",
    "exploit",
    "become",
    "steal",
    "remove",
    "belong",
    "force",
    "impose",
    "plunge",
    "stir",
    "express",
    "cool",
    "result",
    "undermine",
    "allocate",
    "cheer",
    "use",
    "sum",
    "squeeze",
    "store",
    "induce",
    "acquire",
    "absorb",
    "cast",
    "report",
    "manipulate",
    "presume",
    "rely",
    "schedule",
    "list",
    "account",
    "identify",
    "going",
    "remind",
    "judge",
    "call",
    "maintain",
    "in",
    "risk",
    "classify",
    "split",
    "compensate",
    "realize",
    "calculate",
    "compare",
    "provide",
    "bring",
    "time",
    "range",
    "invite",
    "underline",
    "point",
    "study",
    "review",
    "obey",
    "prescribe",
    "deny",
    "reach",
    "depend",
    "arise",
    "wash",
    "edit",
    "carry",
    "transmit",
    "perform",
    "find",
    "exercise",
    "shoot",
    "satisfy",
    "strip",
    "drag",
    "wonder",
    "sound",
    "want",
]
