adjectives = [
    "practical",
    "famous",
    "healthy",
    "unusual",
    "happy",
    "logical",
    "severe",
    "federal",
    "immediate",
    "responsible",
    "lucky",
    "additional",
    "suspicious",
    "intelligent",
    "strong",
    "existing",
    "careful",
    "distinct",
    "psychological",
    "desperate",
    "serious",
    "odd",
    "eastern",
    "political",
    "similar",
    "anxious",
    "legal",
    "useful",
    "tiny",
    "sudden",
    "aware",
    "interesting",
    "technical",
    "basic",
    "strict",
    "embarrassed",
    "significant",
    "aggressive",
    "nervous",
    "traditional",
    "mad",
    "typical",
    "medical",
    "recent",
    "various",
    "unable",
    "electronic",
    "cultural",
    "administrative",
    "sorry",
    "competitive",
    "unhappy",
    "hungry",
    "huge",
    "difficult",
    "remarkable",
    "informal",
    "used",
    "lonely",
    "rare",
    "global",
    "expensive",
    "critical",
    "exciting",
    "southern",
    "realistic",
    "tall",
    "hot",
    "accurate",
    "environmental",
    "helpful",
    "dangerous",
    "ugly",
    "several",
    "entire",
    "willing",
    "large",
    "emotional",
    "nice",
    "conscious",
    "wooden",
    "different",
    "historical",
    "important",
    "obviously",
    "curious",
    "acceptable",
    "capable",
    "latter",
    "powerful",
    "automatic",
    "successful",
    "comprehensive",
    "angry",
    "impressive",
    "visible",
    "united",
    "efficient",
    "afraid",
    "asleep",
    "strange",
    "actual",
    "consistent",
    "numerous",
    "confident",
    "available",
    "civil",
    "popular",
    "dramatic",
    "scared",
    "able",
    "impossible",
    "inner",
    "known",
    "boring",
    "old",
    "unlikely",
    "mental",
    "relevant",
    "substantial",
    "foreign",
    "every",
    "suitable",
    "poor",
    "pleasant",
    "cute",
    "weak",
    "wonderful",
]

