adverbs = [
    "quietly",
    "dutifully",
    "carefully",
    "crossly",
    "unethically",
    "helplessly",
    "lightly",
    "only",
    "intently",
    "angrily",
    "curiously",
    "evenly",
    "almost",
    "politely",
    "sadly",
    "mockingly",
    "unbearably",
    "loftily",
    "elegantly",
    "majestically",
    "quickly",
    "excitedly",
    "tediously",
    "upright",
    "needily",
    "questionably",
    "instantly",
    "uselessly",
    "helpfully",
    "warmly",
    "confidently",
    "virtually",
    "briskly",
    "brightly",
    "bleakly",
    "neatly",
    "hopelessly",
    "wrongly",
    "somewhat",
    "slightly",
    "always",
    "valiantly",
    "deftly",
    "eagerly",
    "unexpectedly",
    "bashfully",
    "vastly",
    "verbally",
    "justly",
    "cautiously",
    "sharply",
    "hastily",
    "rarely",
    "oddly",
    "utterly",
    "madly",
    "ultimately",
    "deeply",
    "selfishly",
    "fully",
    "repeatedly",
    "noisily",
    "crazily",
    "originally",
]

